@@ -49,6 +49,7 @@ from tendenci.addons.corporate_memberships.utils import (
 from tendenci.addons.corporate_memberships.settings import UPLOAD_ROOT
 from tendenci.core.base.fields import SplitDateTimeField
 from tendenci.core.payments.models import PaymentMethod
+from tendenci.core.site_settings.utils import get_setting
 
 fs = FileSystemStorage(location=UPLOAD_ROOT)
 
@@ -82,12 +83,20 @@ class CorporateMembershipTypeForm(forms.ModelForm):
                   'individual_threshold',
                   'individual_threshold_price',
                   'admin_only',
+                  'number_passes',
                   'position',
                   'status',
                   'status_detail',
                   )
 
 
+class FreePassesForm(forms.ModelForm):
+
+    class Meta:
+        model = CorpMembership
+        fields = ('total_passes_allowed',)
+
+
 class CorpMembershipAppForm(TendenciBaseForm):
     description = forms.CharField(required=False,
                      widget=TinyMCE(
