@@ -432,7 +432,7 @@ def form_detail(request, slug, template="forms/form_detail.html"):
             # fields aren't included in submitter body to prevent spam
             submitter_body = generate_submitter_email_body(entry, form_for_form)
             email_from = form.email_from or settings.DEFAULT_FROM_EMAIL
-            sender = get_setting('site', 'global', 'siteemailnoreplyaddress')
+            sender = get_setting('site', 'global', 'siteemailnoreplyaddress') or settings.DEFAULT_FROM_EMAIL
             email_to = form_for_form.email_to()
             if email_to and form.send_email and form.email_text:
                 # Send message to the person who submitted the form.
